******************
Displaying Spectra
******************

Words go here


Pan/Zoom
========

More words...

Defining Spectral Regions
=========================

More words...

Plot Settings
=============

More words...